==> tomcat-plugin-1.3.2-sources.jar: com/xebialabs/deployit/plugin/tomcat/mapper/LibrariesToTomcatServerMapper.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.tomcat.mapper;

import com.xebialabs.deployit.Change;
import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.ci.Deployment;
import com.xebialabs.deployit.ci.Host;
import com.xebialabs.deployit.ci.artifact.Libraries;
import com.xebialabs.deployit.mapper.StepGeneratingMapper;
import com.xebialabs.deployit.plugin.tomcat.ci.TomcatLibrariesMapping;
import com.xebialabs.deployit.plugin.tomcat.ci.TomcatServer;
import com.xebialabs.deployit.steps.CopyStep;
import com.xebialabs.deployit.steps.DeleteStep;

import java.io.File;
import java.util.List;

/**
 * Mapper that maps {@link com.xebialabs.deployit.ci.artifact.Libraries} CI's to {@link com.xebialabs.deployit.plugin.tomcat.ci.TomcatServer tomcatServer} with {@link com.xebialabs.deployit.plugin.tomcat.ci.TomcatLibrariesMapping} CI's.
 */

public class LibrariesToTomcatServerMapper extends StepGeneratingMapper<Libraries, TomcatLibrariesMapping, TomcatServer> {
	public LibrariesToTomcatServerMapper(Change<Deployment> change) {
		super(change, false);
	}

	@Override
	protected void generateAdditionStepsForAddedMapping(Libraries newMappingSource, TomcatLibrariesMapping m, TomcatServer newMappingTarget, List<Step> steps) {
		String targetDirectory = newMappingTarget.getTomcatLibDirectory();
		steps.add(new CopyStep(Host.getLocalHost(), m.getSource().getLocation(), m.getTarget().getHost(), targetDirectory));
	}

	@Override
	protected void generateDeletionStepsForDeletedMapping(Libraries oldMappingSource, TomcatLibrariesMapping m, TomcatServer oldMappingTarget, List<Step> steps) {
		String targetDirectory = oldMappingTarget.getTomcatLibDirectory();
		for (File f : oldMappingSource.getFiles()) {
			String fileToDelete = new File(targetDirectory, f.getName()).getPath();
			steps.add(new DeleteStep(m.getTarget().getHost(), fileToDelete));
		}
	}
}

==> tomcat-plugin-1.4-sources.jar: com/xebialabs/deployit/plugin/tomcat/mapper/LibrariesToTomcatServerMapper.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.tomcat.mapper;

import com.xebialabs.deployit.Change;
import com.xebialabs.deployit.ci.Deployment;
import com.xebialabs.deployit.ci.artifact.Libraries;
import com.xebialabs.deployit.mapper.artifact.FolderToHostMapper;
import com.xebialabs.deployit.plugin.tomcat.ci.TomcatLibrariesMapping;
import com.xebialabs.deployit.plugin.tomcat.ci.TomcatServer;

/**
 * Mapper that maps {@link com.xebialabs.deployit.ci.artifact.Libraries} CI's to {@link com.xebialabs.deployit.plugin.tomcat.ci.TomcatServer tomcatServer} with {@link com.xebialabs.deployit.plugin.tomcat.ci.TomcatLibrariesMapping} CI's.
 */

public class LibrariesToTomcatServerMapper extends FolderToHostMapper<Libraries, TomcatLibrariesMapping, TomcatServer> {

	public LibrariesToTomcatServerMapper(Change<Deployment> change) {
		super(change);
	}
}
